<?php

namespace InterludeSante\Statistics;

use InterludeSante\Statistics\Model;

class Table
{
    /**
     * Retrieve Table by name action.
     * @access public
     *
     * @param string $name
     *
     * @return array
     */
    public static function get(string $name)
    {
        $table = self::getAction($name);

        return $table;
    }

    /**
     * Retrieves actions data by establishment according to the given parameters.
     * @access private
     *
     * @param string $action_name
     * @param string $type
     *
     * @return array
     */
    private static function getAction(string $action_name)
    {
        $data = [];


        $data['headings'] = self::getHeadings($action_name);
        $data['raw'] = Model::getAction($action_name);

        $data['items'] = self::formatData($data['raw'], $action_name);

        return $data;
    }

    /**
     * Retrieves columns headings according action.
     * @access private
     *
     * @param string $action_name
     *
     * @return array
     */
    private static function getHeadings(string $action_name)
    {
        $headings = [];
        if ($action_name === 'page') {
            $headings = [
                __('URL', 'ullis-statistics'),
                __('Nombre de vue', 'ullis-statistics')
            ];
        }

        return $headings;
    }

    /**
     * Format according data
     * @access private
     *
     * @param array $raw
     * @param string $action
     *
     * @return array
     */
    private static function formatData($raw, $action = 'page')
    {
        switch ($action) {
            // case 'page':
            //     # code...
            //     break;
            default:
                $total_url = array_map(function ($item) {
                    return $item['screen'];
                }, $raw);

                $data = array_count_values($total_url);
                array_multisort($data, SORT_DESC, $data);
                break;
        }

        return $data;
    }
}
